#[repr(i32)]pub enum ResponseType {
Samples = 0,
StreamedXorChunks = 1,
}Variants
Samples = 0
Server will return a single ReadResponse message with matched series that includes list of raw samples. It’s recommended to use streamed response types instead.
Response headers: Content-Type: “application/x-protobuf” Content-Encoding: “snappy”
StreamedXorChunks = 1
Server will stream a delimited ChunkedReadResponse message that contains XOR or HISTOGRAM(!) encoded chunks for a single series. Each message is following varint size and fixed size bigendian uint32 for CRC32 Castagnoli checksum.
Response headers: Content-Type: “application/x-streamed-protobuf; proto=prometheus.ChunkedReadResponse” Content-Encoding: “”
Implementations
Sourceimpl ResponseType
impl ResponseType
Sourceimpl ResponseType
impl ResponseType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.